import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:sk_base_mobile/app_theme.dart';
import 'package:sk_base_mobile/util/screen_adaper_util.dart';
import 'package:sk_base_mobile/widgets/core/sk_base_field.dart';
import 'package:sk_base_mobile/widgets/core/sk_form_item.dart';
import 'package:sk_base_mobile/widgets/core/sk_tag.dart';
import 'package:multi_dropdown/multiselect_dropdown.dart';

class SkMultiPickerDropdown<T> extends SkBaseFieldWidget {
  final TextEditingController textController;
  final Function(FocusNode)? onTap;
  final bool isRequired;
  final String? labelText;
  final String? hint;
  final bool isTextArea;
  final bool isDense;
  final Function(String)? onTapOutside;
  final Function(String)? onChanged;
  final String? Function(String?)? validator;
  final EdgeInsetsGeometry? contentPadding;
  final ValueChanged<String>? onFieldSubmitted;
  final Icon? prefix;
  final Widget? suffixIcon;
  final InputBorder? border;
  final FloatingLabelBehavior? floatingLabelBehavior;
  final TextInputType? keyboardType;
  SkMultiPickerDropdown(
      {super.key,
      required this.textController,
      super.customLabel = false,
      super.autoFocus = false,
      this.onTap,
      this.hint,
      this.onFieldSubmitted,
      this.isRequired = false,
      this.onTapOutside,
      this.keyboardType,
      this.labelText,
      this.prefix,
      this.suffixIcon,
      this.onChanged,
      this.border,
      this.floatingLabelBehavior = FloatingLabelBehavior.always,
      this.isTextArea = false,
      this.contentPadding,
      this.isDense = false,
      this.validator});

  @override
  Widget build(BuildContext context) {
    return SkFormItem(
        child: MultiSelectDropDown<int>(
          focusNode: focusNode,
          onOptionSelected: (List<ValueItem> selectedOptions) {},
          options: <ValueItem<int>>[
            ValueItem(label: 'Option 1', value: 1),
            ValueItem(label: 'Option 2', value: 2),
            ValueItem(label: 'Option 3', value: 3),
            ValueItem(label: 'Option 4', value: 4),
            ValueItem(label: 'Option 5', value: 5),
            ValueItem(label: 'Option 6', value: 6),
          ],
          borderColor: AppTheme.nearlyBlack,
          fieldBackgroundColor: AppTheme.inputFillColor,
          borderWidth: 1,
          borderRadius: ScreenAdaper.sp(15),
          focusedBorderWidth: 2,
          focusedBorderColor: AppTheme.primaryColorLight,
          hint: '请选择',
          hintStyle: Theme.of(Get.context!).inputDecorationTheme.hintStyle,
          hintPadding: EdgeInsets.symmetric(horizontal: ScreenAdaper.width(5)),
          selectionType: SelectionType.multi,
          chipConfig: const ChipConfig(wrapType: WrapType.scroll),
          optionTextStyle: const TextStyle(fontSize: 16),
          selectedOptionIcon: const Icon(Icons.check_circle),
        ),
        customLabel: customLabel,
        labelText: labelText,
        isRequired: isRequired,
        controller: baseFieldController);

    // return DropdownButtonFormField<String>(
    //   focusNode: focusNode,
    //   onTap: () {
    //     if (widget.onTap != null) {
    //       widget.onTap!(focusNode);
    //     }
    //   },
    //   icon: Icon(Icons.arrow_drop_down),
    //   selectedItemBuilder: (context) => [
    //     Container(
    //       width: ScreenAdaper.width(200),
    //       child: SingleChildScrollView(
    //         scrollDirection: Axis.horizontal,
    //         child: Row(mainAxisSize: MainAxisSize.min, children: [
    //           SkTag(text: '角色', color: AppTheme.primaryColor),
    //           SkTag(text: '角色', color: AppTheme.primaryColor),
    //           SkTag(text: '角色', color: AppTheme.primaryColor),
    //           SkTag(text: '角色', color: AppTheme.primaryColor),
    //           SkTag(text: '角色', color: AppTheme.primaryColor),
    //           SkTag(text: '角色', color: AppTheme.primaryColor),
    //           SkTag(text: '角色', color: AppTheme.primaryColor),
    //           SkTag(text: '角色', color: AppTheme.primaryColor),
    //           SkTag(text: '角色', color: AppTheme.primaryColor),
    //           SkTag(text: '角色', color: AppTheme.primaryColor),
    //         ]),
    //       ),
    //     )
    //   ],
    //   autovalidateMode: AutovalidateMode.onUserInteraction,
    //   decoration: InputDecoration(
    //     prefixIcon: widget.prefix,
    //     errorStyle: const TextStyle(fontSize: 0, height: 0.01),
    //     contentPadding: widget.contentPadding,
    //     isDense: widget.isDense,
    //     border: widget.border,
    //     floatingLabelBehavior: widget.floatingLabelBehavior,
    //     label: widget.labelText != null
    //         ? Row(
    //             crossAxisAlignment: CrossAxisAlignment.center,
    //             mainAxisSize: MainAxisSize.min,
    //             children: [
    //                 if (widget.isRequired)
    //                   Text(
    //                     "*",
    //                     style: TextStyle(
    //                         color: Colors.red,
    //                         fontSize: ScreenAdaper.height(30)),
    //                   ),
    //                 Text(
    //                   widget.labelText!,
    //                   style: TextStyle(fontSize: ScreenAdaper.height(30)),
    //                 ),
    //               ])
    //         : null,
    //     focusedBorder: OutlineInputBorder(
    //         borderSide:
    //             const BorderSide(color: AppTheme.primaryColorLight, width: 2),
    //         borderRadius: BorderRadius.circular(ScreenAdaper.sp(15))),
    //     hintText: widget.hint ?? '请输入',
    //   ),
    //   items: [],
    //   onChanged: (Object? value) {},
    // );
  }
}
